@@ -101,23 +101,29 @@ case 'changepassword':
 	}
 	$password_old = md5(get_nfilter_request_var('password'));
 
-	// Get old password to compare against the database 
-	if (function_exists('password_hash')) {
-		$current_password_new = password_hash(get_nfilter_request_var('current_password'), PASSWORD_DEFAULT);
-	}else{
-		$current_password_new = '';
-	}
 	$current_password_old = md5(get_nfilter_request_var('current_password'));
 
 	// Password and Confirmed password checks
-	if ((!password_verify(get_nfilter_request_var('current_password'), $user['password'])) && $user['password'] != $current_password_old) {
-		$bad_password = true;
-		$errorMessage = "<span class='badpassword_message'>" . __('Your current password is not correct. Please try again.') . "</span>";
-	}
+	if (function_exists('password_verify')) {
+		if ((!password_verify(get_nfilter_request_var('current_password'), $user['password'])) && $user['password'] != $current_password_old) {
+			$bad_password = true;
+			$errorMessage = "<span class='badpassword_message'>" . __('Your current password is not correct. Please try again.') . "</span>";
+		}
 
-	if (password_verify(get_nfilter_request_var('password'), $user['password']) || $user['password'] == $password_old) {
-		$bad_password = true;
-		$errorMessage = "<span class='badpassword_message'>" . __('Your new password cannot be the same as the old password. Please try again.') . "</span>";
+		if (password_verify(get_nfilter_request_var('password'), $user['password']) || $user['password'] == $password_old) {
+			$bad_password = true;
+			$errorMessage = "<span class='badpassword_message'>" . __('Your new password cannot be the same as the old password. Please try again.') . "</span>";
+		}
+	}else{
+		if ($user['password'] != $current_password_old) {
+			$bad_password = true;
+			$errorMessage = "<span class='badpassword_message'>" . __('Your current password is not correct. Please try again.') . "</span>";
+		}
+
+		if ($user['password'] == $password_old) {
+			$bad_password = true;
+			$errorMessage = "<span class='badpassword_message'>" . __('Your new password cannot be the same as the old password. Please try again.') . "</span>";
+		}
 	}
 	
 	if (get_nfilter_request_var('password') !== (get_nfilter_request_var('confirm'))) {
@@ -244,17 +250,22 @@ if (read_config_option('secpass_history') != '0') {
 
 $secpass_tooltip .= $secpass_body;
 
+$selectedTheme = get_selected_theme();
+
 print "<!DOCTYPE html>\n";
 print "<html>\n";
 print "<head>\n";
 print "\t<title>" . __('Change Password') . "</title>\n";
 print "\t<meta http-equiv='Content-Type' content='text/html;charset=utf-8'>\n";
+print "\t<meta content='width=device-width, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0' name='viewport'>\n";
+print "\t<meta name='apple-mobile-web-app-capable' content='yes'>\n";
+print "\t<meta name='mobile-web-app-capable' content='yes'>\n";
 print "\t<meta http-equiv='X-UA-Compatible' content='IE=Edge,chrome=1'>\n";
-print "\t<link href='" . $config['url_path'] . "include/themes/" . get_selected_theme() . "/jquery-ui.css' type='text/css' rel='stylesheet'>\n";
+print "\t<link href='" . $config['url_path'] . "include/themes/" . $selectedTheme . "/jquery-ui.css' type='text/css' rel='stylesheet'>\n";
 print "\t<link href='" . $config['url_path'] . "include/" .  "/fa/css/font-awesome.css' type='text/css' rel='stylesheet'>\n";
-print "\t<link href='" . $config['url_path'] . "include/themes/" . get_selected_theme() . "/main.css' type='text/css' rel='stylesheet'>\n";
-print "\t<link href='" . $config['url_path'] . "include/themes/" . get_selected_theme() . "/images/favicon.ico' rel='shortcut icon'>\n";
-print "\t<link href='" . $config['url_path'] . "include/themes/" . get_selected_theme() . "/images/cacti_logo.gif' rel='icon' sizes='96x96'>\n";
+print "\t<link href='" . $config['url_path'] . "include/themes/" . $selectedTheme . "/main.css' type='text/css' rel='stylesheet'>\n";
+print "\t<link href='" . $config['url_path'] . "include/themes/" . $selectedTheme . "/images/favicon.ico' rel='shortcut icon'>\n";
+print "\t<link href='" . $config['url_path'] . "include/themes/" . $selectedTheme . "/images/cacti_logo.gif' rel='icon' sizes='96x96'>\n";
 print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/js/jquery.js' language='javascript'></script>\n";
 print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/js/jquery-migrate.js' language='javascript'></script>\n";
 print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/js/jquery-ui.js' language='javascript'></script>\n";
@@ -262,8 +273,8 @@ print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/
 print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/js/jquery.tablesorter.js' language='javascript'></script>\n";
 print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/js/jquery.hotkeys.js'></script>\n";
 print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/layout.js'></script>\n";
-print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/themes/" . get_selected_theme() . "/main.js'></script>\n";
-print "<script type='text/javascript'>var theme='" . get_selected_theme() . "';</script>\n";
+print "\t<script type='text/javascript' src='" . $config['url_path'] . "include/themes/" . $selectedTheme . "/main.js'></script>\n";
+print "<script type='text/javascript'>var theme='" . $selectedTheme . "';</script>\n";
 print "</head>\n";
 print "<body class='loginBody'>
 	<div class='loginLeft'></div>
