@@ -565,7 +565,7 @@ function draw_filter() {
 			});
 
 			$('#export').click(function() {
-				document.location = 'automation_devices.php?export=1';
+				document.location = 'automation_devices.php?action=export';
 			});
 		});
 	
