@@ -392,6 +392,7 @@ function network_edit() {
 	'spacer0' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('General Settings'),
+		'collapsible' => 'true'
 		),
 	'name' => array(
 		'method' => 'textbox',
@@ -508,6 +509,7 @@ function network_edit() {
 	'spacer2' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('Discovery Timing'),
+		'collapsible' => 'true'
 		),
 	'start_at' => array(
 		'method' => 'textbox',
@@ -611,6 +613,7 @@ function network_edit() {
 	'spacer1' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('Reachability Settings'),
+		'collapsible' => 'true'
 		),
 	'snmp_id' => array(
 		'method' => 'drop_sql',
@@ -855,16 +858,21 @@ function get_networks(&$sql_where, $rows, $apply_limits = TRUE) {
 		$sql_where = " WHERE (automation_networks.name LIKE '%" . get_request_var('filter') . "%')";
 	}
 
+	$sql_order = get_order_string();
+
+	if ($apply_limits) {
+		$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
+	}else{
+		$sql_limit = '';
+	}
+
 	$query_string = "SELECT automation_networks.*, poller.name AS data_collector
 		FROM automation_networks
 		LEFT JOIN poller
 		ON automation_networks.poller_id=poller.id
 		$sql_where
-		ORDER BY " . get_request_var('sort_column') . ' ' . get_request_var('sort_direction');
-
-	if ($apply_limits) {
-		$query_string .= ' LIMIT ' . ($rows*(get_request_var('page') -1)) . ',' . $rows;
-	}
+		$sql_order
+		$sql_limit";
 
 	return db_fetch_assoc($query_string);
 }
