@@ -1,5 +1,4 @@
 function themeReady() {
-	var pageName = basename($(location).attr('pathname'));
 	var hostTimer = false;
 	var clickTimeout = false;
 	var hostOpen = false;
@@ -9,15 +8,6 @@ function themeReady() {
 	$('#navigation_right').css('height', ($(window).height()-80)+'px');
 	$('.formItemDescription').hide();
 
-	$(window).resize(function(event) {
-		$('body').css('height', $(window).height());
-
-		if (!$(event.target).hasClass('ui-resizable')) {
-			$('#navigation').css('height', ($(window).height()-80)+'px');
-			$('#navigation_right').css('height', ($(window).height()-80)+'px');
-		}
-	});
-
 	// Setup the navigation menu
 	setMenuVisibility();
 
