@@ -643,6 +643,10 @@ function dsstats_poller_output(&$rrd_update_array) {
 							$last_delim = ', ';
 						}
 
+						if ($currentval == '') {
+							$currentval = 'NULL';
+						}
+
 						/* setupt the output buffer for the cache first */
 						$cachebuf .=
 							$cache_delim . '(' .
