@@ -33,7 +33,7 @@
 function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentile = 95, $resolution = 0) {
 	global $config;
 
-	include_once($config["library_path"] . "/rrd.php");
+	include_once($config['library_path'] . '/rrd.php');
 
 	$values_array = array();
 
@@ -50,16 +50,16 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 			$fetch_array[$i] = @rrdtool_function_fetch($ldi, $start_seconds, $end_seconds, $resolution);
 			/* clean up unwanted data source items */
 			if (! empty($fetch_array[$i])) {
-				while (list($id, $name) = each($fetch_array[$i]["data_source_names"])) {
+				while (list($id, $name) = each($fetch_array[$i]['data_source_names'])) {
 					/* get rid of the Nth max for now since we'll need to re-calculate it later */
-					if ($name == "nth_percentile_maximum") {
-						unset($fetch_array[$i]["data_source_names"][$id]);
-						unset($fetch_array[$i]["values"][$id]);
+					if ($name == 'nth_percentile_maximum') {
+						unset($fetch_array[$i]['data_source_names'][$id]);
+						unset($fetch_array[$i]['values'][$id]);
 					}
 					/* clean up DS items that aren't defined on the graph */
 					if (! in_array($name, $local_data_id[$ldi])) {
-						unset($fetch_array[$i]["data_source_names"][$id]);
-						unset($fetch_array[$i]["values"][$id]);
+						unset($fetch_array[$i]['data_source_names'][$id]);
+						unset($fetch_array[$i]['values'][$id]);
 					}
 				}
 				$i++;
@@ -67,11 +67,11 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 		}
 
 		/* Create our array for working  */
-		if (empty($fetch_array[0]["data_source_names"])) {
+		if (empty($fetch_array[0]['data_source_names'])) {
 			/* here to avoid warning on non-exist file */
 			$fetch_array = array();
 		}else{
-			$sum_array["data_source_names"] = $fetch_array[0]["data_source_names"];
+			$sum_array['data_source_names'] = $fetch_array[0]['data_source_names'];
 		}
 
 		if (sizeof($fetch_array) > 0) {
@@ -82,8 +82,8 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 			reset($fetch_array);
 			for ($i=0; $i<count($fetch_array); $i++) {
 				/* Go through data souce names */
-				reset($fetch_array[$i]["data_source_names"]);
-				foreach ( $fetch_array[$i]["data_source_names"] as $ds_name ) {
+				reset($fetch_array[$i]['data_source_names']);
+				foreach ($fetch_array[$i]['data_source_names'] as $ds_name) {
 					$dsi_name_to_id[$ds_name][] = $i;
 				}
 			}
@@ -92,20 +92,20 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 			$sum_array = array();
 			$i = 0;
 			foreach ( $dsi_name_to_id as $ds_name => $id_array ) {
-				$sum_array["data_source_names"][$i] = $ds_name;
+				$sum_array['data_source_names'][$i] = $ds_name;
 				foreach ($id_array as $id) {
-					$fetch_id = array_search($ds_name,$fetch_array[$id]["data_source_names"]);
+					$fetch_id = array_search($ds_name,$fetch_array[$id]['data_source_names']);
 						/* Sum up like ds names */
-						for ($j=0; $j<count($fetch_array[$id]["values"][$fetch_id]); $j++) {
-							if (isset($fetch_array[$id]["values"][$fetch_id][$j])) {
-								$value = $fetch_array[$id]["values"][$fetch_id][$j];
+						for ($j=0; $j<count($fetch_array[$id]['values'][$fetch_id]); $j++) {
+							if (isset($fetch_array[$id]['values'][$fetch_id][$j])) {
+								$value = $fetch_array[$id]['values'][$fetch_id][$j];
 							}else{
 								$value = 0;
 							}
-							if (isset($sum_array["values"][$i][$j])) {
-								$sum_array["values"][$i][$j] += $value;
+							if (isset($sum_array['values'][$i][$j])) {
+								$sum_array['values'][$i][$j] += $value;
 							}else{
-								$sum_array["values"][$i][$j] = $value;
+								$sum_array['values'][$i][$j] = $value;
 							}
 						}
 				}
@@ -114,38 +114,38 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 		}
 
 		/* calculate extra data, max, sum */
-		if (isset($sum_array["values"])) {
-			$num_ds = count($sum_array["values"]);
-			$total_ds = count($sum_array["values"]);
+		if (isset($sum_array['values'])) {
+			$num_ds = count($sum_array['values']);
+			$total_ds = count($sum_array['values']);
 			for ($j=0; $j<$total_ds; $j++) { /* each data source item */
-				for ($k=0; $k<count($sum_array["values"][$j]); $k++) { /* each rrd row */
+				for ($k=0; $k<count($sum_array['values'][$j]); $k++) { /* each rrd row */
 					/* now we must re-calculate the 95th max */
 					$value = 0;
-					if (isset($sum_array["values"][$j][$k])) {
-						$value = $sum_array["values"][$j][$k];
+					if (isset($sum_array['values'][$j][$k])) {
+						$value = $sum_array['values'][$j][$k];
 					}
-					if (isset($sum_array["values"][$num_ds][$k])) {
-						$sum_array["values"][$num_ds][$k] = max($value, $sum_array["values"][$num_ds][$k]);
+					if (isset($sum_array['values'][$num_ds][$k])) {
+						$sum_array['values'][$num_ds][$k] = max($value, $sum_array['values'][$num_ds][$k]);
 					}else{
-						$sum_array["values"][$num_ds][$k] = max($value, 0);
+						$sum_array['values'][$num_ds][$k] = max($value, 0);
 					}
 					/* sum of all ds rows */
 					$value = 0;
-					if (isset($sum_array["values"][$j][$k])) {
-						$value = $sum_array["values"][$j][$k];
+					if (isset($sum_array['values'][$j][$k])) {
+						$value = $sum_array['values'][$j][$k];
 					}
 
-					if (isset($sum_array["values"][$num_ds + 1][$k])) {
-						$sum_array["values"][$num_ds + 1][$k] += $value;
+					if (isset($sum_array['values'][$num_ds + 1][$k])) {
+						$sum_array['values'][$num_ds + 1][$k] += $value;
 					}else{
-						$sum_array["values"][$num_ds + 1][$k] = $value;
+						$sum_array['values'][$num_ds + 1][$k] = $value;
 					}
 
 				}
 			}
 
-			$sum_array["data_source_names"][$num_ds] = "nth_percentile_aggregate_max";
-			$sum_array["data_source_names"][$num_ds + 1] = "nth_percentile_aggregate_sum";
+			$sum_array['data_source_names'][$num_ds] = 'nth_percentile_aggregate_max';
+			$sum_array['data_source_names'][$num_ds + 1] = 'nth_percentile_aggregate_sum';
 
 		}
 
@@ -156,12 +156,12 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 	}
 
 	/* loop through each data source */
-	if (empty($fetch_array["data_source_names"])) {
+	if (empty($fetch_array['data_source_names'])) {
 		$return_array = array();
 	}else{
-		for ($i=0; $i<count($fetch_array["data_source_names"]); $i++) {
-			if (isset($fetch_array["values"][$i])) {
-				$values_array = $fetch_array["values"][$i];
+		for ($i=0; $i<count($fetch_array['data_source_names']); $i++) {
+			if (isset($fetch_array['values'][$i])) {
+				$values_array = $fetch_array['values'][$i];
 
 				/* sort the array in descending order */
 				rsort($values_array, SORT_NUMERIC);
@@ -171,23 +171,23 @@ function nth_percentile($local_data_id, $start_seconds, $end_seconds, $percentil
 			value */
 			$inverse_percentile = 1 - ($percentile / 100);
 			$target = ((count($values_array) + 1) * $inverse_percentile);
-			$target = sprintf("%d", $target);
+			$target = sprintf('%d', $target);
 
 			if (empty($values_array[$target])) { $values_array[$target] = 0; }
 
 			/* collect Nth percentile values in this array so we can return them */
-			$return_array{$fetch_array["data_source_names"][$i]} = $values_array[$target];
+			$return_array{$fetch_array['data_source_names'][$i]} = $values_array[$target];
 
 			/* get max Nth calculation for aggregate */
-			if (($fetch_array["data_source_names"][$i] != "nth_percentile_aggregate_max") &&
-				($fetch_array["data_source_names"][$i] != "nth_percentile_aggregate_sum") &&
-				($fetch_array["data_source_names"][$i] != "nth_percentile_maximum")) {
-				if (isset($return_array{"nth_percentile_aggregate_total"})) {
-					if (($return_array{"nth_percentile_aggregate_total"} < $values_array[$target])) {
-						$return_array{"nth_percentile_aggregate_total"} = $values_array[$target];
+			if (($fetch_array['data_source_names'][$i] != 'nth_percentile_aggregate_max') &&
+				($fetch_array['data_source_names'][$i] != 'nth_percentile_aggregate_sum') &&
+				($fetch_array['data_source_names'][$i] != 'nth_percentile_maximum')) {
+				if (isset($return_array{'nth_percentile_aggregate_total'})) {
+					if (($return_array{'nth_percentile_aggregate_total'} < $values_array[$target])) {
+						$return_array{'nth_percentile_aggregate_total'} = $values_array[$target];
 					}
 				}else{
-					$return_array{"nth_percentile_aggregate_total"} = $values_array[$target];
+					$return_array{'nth_percentile_aggregate_total'} = $values_array[$target];
 				}
 			}
 		}
@@ -279,30 +279,30 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 	}
 
 	/* Get the Nth percentile values */
-	if (($regexp_match_array[4] == "current") || ($regexp_match_array[4] == "max")) {
-		$nth_cache{$graph_item["local_data_id"]} = nth_percentile($graph_item["local_data_id"], $graph_start, $graph_end, $regexp_match_array[1]);
-	}elseif (($regexp_match_array[4] == "total") || ($regexp_match_array[4] == "total_peak") || ($regexp_match_array[4] == "all_max_current") || ($regexp_match_array[4] == "all_max_peak")) {
+	if (($regexp_match_array[4] == 'current') || ($regexp_match_array[4] == 'max')) {
+		$nth_cache{$graph_item['local_data_id']} = nth_percentile($graph_item['local_data_id'], $graph_start, $graph_end, $regexp_match_array[1]);
+	}elseif (($regexp_match_array[4] == 'total') || ($regexp_match_array[4] == 'total_peak') || ($regexp_match_array[4] == 'all_max_current') || ($regexp_match_array[4] == 'all_max_peak')) {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if (!empty($graph_items[$t]["local_data_id"])) {
-				$nth_cache{$graph_items[$t]["local_data_id"]} = nth_percentile($graph_items[$t]["local_data_id"], $graph_start, $graph_end, $regexp_match_array[1]);
+			if (!empty($graph_items[$t]['local_data_id'])) {
+				$nth_cache{$graph_items[$t]['local_data_id']} = nth_percentile($graph_items[$t]['local_data_id'], $graph_start, $graph_end, $regexp_match_array[1]);
 			}
 		}
-	}elseif (($regexp_match_array[4] == "aggregate") || ($regexp_match_array[4] == "aggregate_sum") || ($regexp_match_array[4] == "aggregate_max")) {
+	}elseif (($regexp_match_array[4] == 'aggregate') || ($regexp_match_array[4] == 'aggregate_sum') || ($regexp_match_array[4] == 'aggregate_max')) {
 		$local_data_array = array();
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
-				$local_data_array[$graph_items[$t]["local_data_id"]][] = $graph_items[$t]["data_source_name"];
+			if ((preg_match('/(AREA|STACK|LINE[123])/', $graph_item_types{$graph_items[$t]['graph_type_id']})) && (!empty($graph_items[$t]['data_template_rrd_id']))) {
+				$local_data_array[$graph_items[$t]['local_data_id']][] = $graph_items[$t]['data_source_name'];
 			}
 		}
                 $nth_cache{0} = nth_percentile($local_data_array, $graph_start, $graph_end, $regexp_match_array[1]);
-	} elseif ($regexp_match_array[4] == "aggregate_current") {
+	} elseif ($regexp_match_array[4] == 'aggregate_current') {
 		$local_data_array = array();
-		if (!empty($graph_item["data_source_name"])) {
+		if (!empty($graph_item['data_source_name'])) {
 			for ($t=0;($t<count($graph_items));$t++) {
-				if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) &&
-					(!empty($graph_items[$t]["data_template_rrd_id"])) &&
-					($graph_item["data_source_name"] == $graph_items[$t]["data_source_name"])) {
-					$local_data_array[$graph_items[$t]["local_data_id"]][] = $graph_items[$t]["data_source_name"];
+				if ((preg_match('/(AREA|STACK|LINE[123])/', $graph_item_types{$graph_items[$t]['graph_type_id']})) &&
+					(!empty($graph_items[$t]['data_template_rrd_id'])) &&
+					($graph_item['data_source_name'] == $graph_items[$t]['data_source_name'])) {
+					$local_data_array[$graph_items[$t]['local_data_id']][] = $graph_items[$t]['data_source_name'];
 				}
 			}
 			$nth_cache{0} = nth_percentile($local_data_array, $graph_start, $graph_end, $regexp_match_array[1]);
@@ -312,18 +312,18 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 	$nth = 0;
 
 	/* format the output according to args passed to the variable */
-	if ($regexp_match_array[4] == "current") {
-		if (! empty($nth_cache{$graph_item["local_data_id"]}{$graph_item["data_source_name"]})) {
-			$nth = $nth_cache{$graph_item["local_data_id"]}{$graph_item["data_source_name"]};
-			$nth = ($regexp_match_array[2] == "bits") ? $nth * 8 : $nth;
+	if ($regexp_match_array[4] == 'current') {
+		if (! empty($nth_cache{$graph_item['local_data_id']}{$graph_item['data_source_name']})) {
+			$nth = $nth_cache{$graph_item['local_data_id']}{$graph_item['data_source_name']};
+			$nth = ($regexp_match_array[2] == 'bits') ? $nth * 8 : $nth;
 			$nth /= pow(10,intval($regexp_match_array[3]));
 		}
-	}elseif ($regexp_match_array[4] == "total") {
+	}elseif ($regexp_match_array[4] == 'total') {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
-				if (! empty($nth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]})) {
-					$local_nth = $nth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]};
-					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
+			if ((preg_match('/(AREA|STACK|LINE[123])/', $graph_item_types{$graph_items[$t]['graph_type_id']})) && (!empty($graph_items[$t]['data_template_rrd_id']))) {
+				if (! empty($nth_cache{$graph_items[$t]['local_data_id']}{$graph_items[$t]['data_source_name']})) {
+					$local_nth = $nth_cache{$graph_items[$t]['local_data_id']}{$graph_items[$t]['data_source_name']};
+					$local_nth = ($regexp_match_array[2] == 'bits') ? $local_nth * 8 : $local_nth;
 					$local_nth /= pow(10,intval($regexp_match_array[3]));
 
 					$nth += $local_nth;
@@ -331,30 +331,30 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 
 			}
 		}
-	}elseif ($regexp_match_array[4] == "max") {
-		if (! empty($nth_cache{$graph_item["local_data_id"]}["nth_percentile_maximum"])) {
-			$nth = $nth_cache{$graph_item["local_data_id"]}["nth_percentile_maximum"];
-			$nth = ($regexp_match_array[2] == "bits") ? $nth * 8 : $nth;
+	}elseif ($regexp_match_array[4] == 'max') {
+		if (! empty($nth_cache{$graph_item['local_data_id']}['nth_percentile_maximum'])) {
+			$nth = $nth_cache{$graph_item['local_data_id']}['nth_percentile_maximum'];
+			$nth = ($regexp_match_array[2] == 'bits') ? $nth * 8 : $nth;
 			$nth /= pow(10,intval($regexp_match_array[3]));
 		}
-	}elseif ($regexp_match_array[4] == "total_peak") {
+	}elseif ($regexp_match_array[4] == 'total_peak') {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
-				if (! empty($nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"])) {
-					$local_nth = $nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"];
-					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
+			if ((preg_match('/(AREA|STACK|LINE[123])/', $graph_item_types{$graph_items[$t]['graph_type_id']})) && (!empty($graph_items[$t]['data_template_rrd_id']))) {
+				if (! empty($nth_cache{$graph_items[$t]['local_data_id']}['nth_percentile_maximum'])) {
+					$local_nth = $nth_cache{$graph_items[$t]['local_data_id']}['nth_percentile_maximum'];
+					$local_nth = ($regexp_match_array[2] == 'bits') ? $local_nth * 8 : $local_nth;
 					$local_nth /= pow(10,intval($regexp_match_array[3]));
 
 					$nth += $local_nth;
 				}
 			}
 		}
-	}elseif ($regexp_match_array[4] == "all_max_current") {
+	}elseif ($regexp_match_array[4] == 'all_max_current') {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
-				if (! empty($ninety_fifth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]})) {
-					$local_nth = $ninety_fifth_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]};
-					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
+			if ((preg_match('/(AREA|STACK|LINE[123])/', $graph_item_types{$graph_items[$t]['graph_type_id']})) && (!empty($graph_items[$t]['data_template_rrd_id']))) {
+				if (! empty($ninety_fifth_cache{$graph_items[$t]['local_data_id']}{$graph_items[$t]['data_source_name']})) {
+					$local_nth = $ninety_fifth_cache{$graph_items[$t]['local_data_id']}{$graph_items[$t]['data_source_name']};
+					$local_nth = ($regexp_match_array[2] == 'bits') ? $local_nth * 8 : $local_nth;
 					$local_nth /= pow(10,intval($regexp_match_array[3]));
 
 					if ($local_nth > $nth) {
@@ -363,12 +363,12 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 				}
 			}
 		}
-	}elseif ($regexp_match_array[4] == "all_max_peak") {
+	}elseif ($regexp_match_array[4] == 'all_max_peak') {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
-				if (! empty($nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"])) {
-					$local_nth = $nth_cache{$graph_items[$t]["local_data_id"]}["nth_percentile_maximum"];
-					$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
+			if ((preg_match('/(AREA|STACK|LINE[123])/', $graph_item_types{$graph_items[$t]['graph_type_id']})) && (!empty($graph_items[$t]['data_template_rrd_id']))) {
+				if (! empty($nth_cache{$graph_items[$t]['local_data_id']}['nth_percentile_maximum'])) {
+					$local_nth = $nth_cache{$graph_items[$t]['local_data_id']}['nth_percentile_maximum'];
+					$local_nth = ($regexp_match_array[2] == 'bits') ? $local_nth * 8 : $local_nth;
 					$local_nth /= pow(10,intval($regexp_match_array[3]));
 
 					if ($local_nth > $nth) {
@@ -377,24 +377,24 @@ function variable_nth_percentile(&$regexp_match_array, &$graph_item, &$graph_ite
 				}
 			}
 		}
-	}elseif (($regexp_match_array[4] == "aggregate") || ($regexp_match_array[4] == "aggregate_current")) {
-		if (! empty($nth_cache{0}["nth_percentile_aggregate_total"])) {
-			$local_nth = $nth_cache{0}["nth_percentile_aggregate_total"];
-			$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
+	}elseif (($regexp_match_array[4] == 'aggregate') || ($regexp_match_array[4] == 'aggregate_current')) {
+		if (! empty($nth_cache{0}['nth_percentile_aggregate_total'])) {
+			$local_nth = $nth_cache{0}['nth_percentile_aggregate_total'];
+			$local_nth = ($regexp_match_array[2] == 'bits') ? $local_nth * 8 : $local_nth;
 			$local_nth /= pow(10,intval($regexp_match_array[3]));
 			$nth = $local_nth;
 		}
-	}elseif ($regexp_match_array[4] == "aggregate_max") {
-		if (! empty($nth_cache{0}["nth_percentile_aggregate_max"])) {
-			$local_nth = $nth_cache{0}["nth_percentile_aggregate_max"];
-			$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
+	}elseif ($regexp_match_array[4] == 'aggregate_max') {
+		if (! empty($nth_cache{0}['nth_percentile_aggregate_max'])) {
+			$local_nth = $nth_cache{0}['nth_percentile_aggregate_max'];
+			$local_nth = ($regexp_match_array[2] == 'bits') ? $local_nth * 8 : $local_nth;
 			$local_nth /= pow(10,intval($regexp_match_array[3]));
 			$nth = $local_nth;
 		}
-	}elseif ($regexp_match_array[4] == "aggregate_sum") {
-		if (! empty($nth_cache{0}["nth_percentile_aggregate_sum"])) {
-			$local_nth = $nth_cache{0}["nth_percentile_aggregate_sum"];
-			$local_nth = ($regexp_match_array[2] == "bits") ? $local_nth * 8 : $local_nth;
+	}elseif ($regexp_match_array[4] == 'aggregate_sum') {
+		if (! empty($nth_cache{0}['nth_percentile_aggregate_sum'])) {
+			$local_nth = $nth_cache{0}['nth_percentile_aggregate_sum'];
+			$local_nth = ($regexp_match_array[2] == 'bits') ? $local_nth * 8 : $local_nth;
 			$local_nth /= pow(10,intval($regexp_match_array[3]));
 			$nth = $local_nth;
 		}
@@ -445,53 +445,53 @@ function variable_bandwidth_summation(&$regexp_match_array, &$graph_item, &$grap
 		$summation_timespan_start = $graph_start;
 	}
 
-	if ($regexp_match_array[2] == "current") {
-		$summation_cache{$graph_item["local_data_id"]} = bandwidth_summation($graph_item["local_data_id"], $summation_timespan_start, $graph_end, $rra_step, $ds_step);
-	}elseif ($regexp_match_array[2] == "total") {
+	if ($regexp_match_array[2] == 'current') {
+		$summation_cache{$graph_item['local_data_id']} = bandwidth_summation($graph_item['local_data_id'], $summation_timespan_start, $graph_end, $rra_step, $ds_step);
+	}elseif ($regexp_match_array[2] == 'total') {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if (!empty($graph_items[$t]["local_data_id"])) {
-				$summation_cache{$graph_items[$t]["local_data_id"]} = bandwidth_summation($graph_items[$t]["local_data_id"], $summation_timespan_start, $graph_end, $rra_step, $ds_step);
+			if (!empty($graph_items[$t]['local_data_id'])) {
+				$summation_cache{$graph_items[$t]['local_data_id']} = bandwidth_summation($graph_items[$t]['local_data_id'], $summation_timespan_start, $graph_end, $rra_step, $ds_step);
 			}
 		}
-	}elseif ($regexp_match_array[2] == "atomic") {
-		$summation_cache{$graph_item["local_data_id"]} = bandwidth_summation($graph_item["local_data_id"], $summation_timespan_start, $graph_end, $rra_step, 1);
+	}elseif ($regexp_match_array[2] == 'atomic') {
+		$summation_cache{$graph_item['local_data_id']} = bandwidth_summation($graph_item['local_data_id'], $summation_timespan_start, $graph_end, $rra_step, 1);
 	}
 
 	$summation = 0;
 
 	/* format the output according to args passed to the variable */
-	if (($regexp_match_array[2] == "current") || ($regexp_match_array[2] == "atomic")) {
-		if (isset($summation_cache{$graph_item["local_data_id"]}{$graph_item["data_source_name"]})) {
-			$summation = $summation_cache{$graph_item["local_data_id"]}{$graph_item["data_source_name"]};
+	if (($regexp_match_array[2] == 'current') || ($regexp_match_array[2] == 'atomic')) {
+		if (isset($summation_cache{$graph_item['local_data_id']}{$graph_item['data_source_name']})) {
+			$summation = $summation_cache{$graph_item['local_data_id']}{$graph_item['data_source_name']};
 		}else{
 			$summation = 0;
 		}
-	}elseif ($regexp_match_array[2] == "total") {
+	}elseif ($regexp_match_array[2] == 'total') {
 		for ($t=0;($t<count($graph_items));$t++) {
-			if ((preg_match("/(AREA|STACK|LINE[123])/", $graph_item_types{$graph_items[$t]["graph_type_id"]})) && (!empty($graph_items[$t]["data_template_rrd_id"]))) {
-				if (isset($summation_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]})) {
-					$summation += $summation_cache{$graph_items[$t]["local_data_id"]}{$graph_items[$t]["data_source_name"]};
+			if ((preg_match('/(AREA|STACK|LINE[123])/', $graph_item_types{$graph_items[$t]['graph_type_id']})) && (!empty($graph_items[$t]['data_template_rrd_id']))) {
+				if (isset($summation_cache{$graph_items[$t]['local_data_id']}{$graph_items[$t]['data_source_name']})) {
+					$summation += $summation_cache{$graph_items[$t]['local_data_id']}{$graph_items[$t]['data_source_name']};
 				}
 			}
 		}
 	}
 
-	if (preg_match("/\d+/", $regexp_match_array[1])) {
+	if (preg_match('/\d+/', $regexp_match_array[1])) {
 		$summation /= pow(10,intval($regexp_match_array[1]));
-	}elseif ($regexp_match_array[1] == "auto") {
+	}elseif ($regexp_match_array[1] == 'auto') {
 		if ($summation < 1000) {
-			$summation_label = "B";
+			$summation_label = 'B';
 		}elseif ($summation < 1000000) {
-			$summation_label = "KB";
+			$summation_label = 'KB';
 			$summation /= 1000;
 		}elseif ($summation < 1000000000) {
-			$summation_label = "MB";
+			$summation_label = 'MB';
 			$summation /= 1000000;
 		}elseif ($summation < 1000000000000) {
-			$summation_label = "GB";
+			$summation_label = 'GB';
 			$summation /= 1000000000;
 		}else{
-			$summation_label = "TB";
+			$summation_label = 'TB';
 			$summation /= 1000000000000;
 		}
 	}
