@@ -581,8 +581,7 @@ function form_save() {
 			}
 		}
 
-		/* reset local settings cache so the user sees the new settings */
-		kill_session_var('sess_graph_config_array');
+		kill_session_var('sess_user_config_array');
 
 		reset_group_perms(get_request_var('id'));
 
@@ -1425,9 +1424,8 @@ function user_group_realms_edit($header_label) {
 			print "<td class='realms' colspan='" . (5-$j) . "'></td>\n";
 			print "</tr>\n";
 		}
-
-		print "</table></td></tr>\n";
 	}
+	print "</table></td></tr>\n";
 
 	/* do plugin realms */
 	$realms = db_fetch_assoc('SELECT pc.name, pr.id AS realm_id, pr.display
